import { platformBrowserDynamic } from '@angular/platform-browser-dynamic';
import * as i0 from '@angular/core';
import { EventEmitter, Component, ViewEncapsulation, Input, NgModule } from '@angular/core';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import { BrowserModule } from '@angular/platform-browser';
import { createCustomElement } from '@angular/elements';

const SIZE = {
    DEFAULT: 'default',
    SMALL: 'small',
    EXTRASMALL: 'xsmall'
};
const APPEARANCE = {
    PRIMARY: 'primary',
    SECONDARY: 'secondary',
    CANCEL: 'cancel',
    DANGER: 'danger',
    SUCCESS: 'success'
};
const TYPE = {
    SUBMIT: 'submit',
    RESET: 'reset',
    BUTTON: 'button'
};
class OscButtonComponent {
    constructor() {
        this.isDropdown = false;
        this.isDisabled = false;
        this.iconOnly = false;
        this.appearance = OscButtonComponent.DEFAULT_BUTTON.APPEARANCE;
        this.size = OscButtonComponent.DEFAULT_BUTTON.SIZE;
        this.iconName = '';
        this.iconSize = OscButtonComponent.ICON_SIZE_MAP[this.size];
        this.type = OscButtonComponent.DEFAULT_BUTTON.TYPE;
        this.onClick = new EventEmitter();
    }
    ngOnInit() {
    }
    getIconId() {
        // To avoid - Strict Contextual Escaping disallows interpolations that concatenate
        // multiple expressions when a trusted value is required
        if (this.iconName) {
            return '#svg-icon-' + this.iconName;
        }
        else {
            return this.iconName;
        }
    }
}
OscButtonComponent.DEFAULT_BUTTON = {
    APPEARANCE: APPEARANCE.PRIMARY,
    SIZE: SIZE.DEFAULT,
    TYPE: TYPE.SUBMIT
};
// Internal Map having what icon size to be used based on button size input.
// Correlates with the font sizes used
OscButtonComponent.ICON_SIZE_MAP = {
    [SIZE.DEFAULT]: 'default',
    [SIZE.SMALL]: 'medium',
    [SIZE.EXTRASMALL]: 'medium'
};
OscButtonComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: OscButtonComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
OscButtonComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.2", type: OscButtonComponent, selector: "lib-osc-button", inputs: { isDropdown: "isDropdown", isDisabled: "isDisabled", iconOnly: "iconOnly", appearance: "appearance", size: "size", iconName: "iconName", iconSize: "iconSize", type: "type", onClick: "onClick" }, ngImport: i0, template: "<button class=\"osc-button size-{{size}} appearance-{{appearance}}\" [disabled]=\"isDisabled\"\n  (click)=\"onClick\" [type]=\"type\">\n  <span ng-if=\"!iconOnly\">\n    <ng-content></ng-content>\n  </span>\n  <!--TODO : will be migrated to icon component in the future -->\n  <svg *ngIf=\"iconOnly\" class=\"osc-svg-icon size-{{iconSize}}\">\n    <use [attr.xlink:href]=\"getIconId()\"></use>\n  </svg>\n  <span *ngIf=\"isDropdown\" class=\"caret\"></span>\n</button>", styles: [".caret{height:20;display:inline-block;width:0;height:0;margin-left:2px;vertical-align:middle;border-top:4px solid;border-right:4px solid transparent;border-left:4px solid transparent}.osc-color-bg-charles{background-color:#1651b0}button.osc-color-bg-charles:hover:enabled{background-color:#00409a}button.osc-color-bg-charles:active:enabled{background-color:#00237a}.osc-color-bd-charles{border:1px solid #1651B0}button.osc-color-bd-charles:hover:enabled{border:1px solid #00409A}button.osc-color-bd-charles:active:enabled{border:1px solid #00237A}.osc-color-txt-on-charles{color:#fff}.osc-color-bg-bunker-hill{background-color:#d2d2d2}button.osc-color-bg-bunker-hill:hover:enabled{background-color:#bababa}button.osc-color-bg-bunker-hill:active:enabled{background-color:#9e9e9e}.osc-color-bd-bunker-hill{border:1px solid #D2D2D2}button.osc-color-bd-bunker-hill:hover:enabled{border:1px solid #BABABA}button.osc-color-bd-bunker-hill:active:enabled{border:1px solid #9E9E9E}.osc-color-txt-on-bunker-hill{color:#333}.osc-color-bg-red-sox{background-color:#bd3039}button.osc-color-bg-red-sox:hover:enabled{background-color:#9b1d2e}button.osc-color-bg-red-sox:active:enabled{background-color:#830a1d}.osc-color-bd-red-sox{border:1px solid #BD3039}button.osc-color-bd-red-sox:hover:enabled{border:1px solid #9B1D2E}button.osc-color-bd-red-sox:active:enabled{border:1px solid #830A1D}.osc-color-txt-on-red-sox{color:#fff}.osc-color-bg-laurel{background-color:#64bc4f}button.osc-color-bg-laurel:hover:enabled{background-color:#4d9a3b}button.osc-color-bg-laurel:active:enabled{background-color:#2f6b23}.osc-color-bd-laurel{border:1px solid #64BC4F}button.osc-color-bd-laurel:hover:enabled{border:1px solid #4D9A3B}button.osc-color-bd-laurel:active:enabled{border:1px solid #2F6B23}.osc-color-txt-on-laurel{color:#fff}.osc-button{display:flex;flex-direction:row;justify-content:center;align-items:center;white-space:nowrap;width:auto;cursor:pointer;gap:4px}.osc-button.appearance-primary{background-color:#1651b0;border:1px solid #1651B0;color:#fff}button.osc-button.appearance-primary:hover:enabled{background-color:#00409a}button.osc-button.appearance-primary:active:enabled{background-color:#00237a}button.osc-button.appearance-primary:hover:enabled{border:1px solid #00409A}button.osc-button.appearance-primary:active:enabled{border:1px solid #00237A}.osc-button.appearance-secondary,.osc-button.appearance-cancel{background-color:#d2d2d2;border:1px solid #D2D2D2;color:#333}button.osc-button.appearance-secondary:hover:enabled,button.osc-button.appearance-cancel:hover:enabled{background-color:#bababa}button.osc-button.appearance-secondary:active:enabled,button.osc-button.appearance-cancel:active:enabled{background-color:#9e9e9e}button.osc-button.appearance-secondary:hover:enabled,button.osc-button.appearance-cancel:hover:enabled{border:1px solid #BABABA}button.osc-button.appearance-secondary:active:enabled,button.osc-button.appearance-cancel:active:enabled{border:1px solid #9E9E9E}.osc-button.appearance-secondary{background-color:#fff}.osc-button.appearance-success{background-color:#64bc4f;border:1px solid #64BC4F;color:#fff}button.osc-button.appearance-success:hover:enabled{background-color:#4d9a3b}button.osc-button.appearance-success:active:enabled{background-color:#2f6b23}button.osc-button.appearance-success:hover:enabled{border:1px solid #4D9A3B}button.osc-button.appearance-success:active:enabled{border:1px solid #2F6B23}.osc-button.appearance-danger{background-color:#bd3039;border:1px solid #BD3039;color:#fff}button.osc-button.appearance-danger:hover:enabled{background-color:#9b1d2e}button.osc-button.appearance-danger:active:enabled{background-color:#830a1d}button.osc-button.appearance-danger:hover:enabled{border:1px solid #9B1D2E}button.osc-button.appearance-danger:active:enabled{border:1px solid #830A1D}.osc-button:focus{outline:2px solid #90CEF1}.osc-button:active,.osc-button :disabled{outline:none}.osc-button:disabled{opacity:40%}.osc-button.size-default{padding:6px 12px;border-radius:4px;font-size:14px;line-height:1.42857143}.osc-button.size-small{padding:5px 10px;border-radius:3px;font-size:12px;line-height:1.5}.osc-button.size-xsmall{padding:1px 5px;border-radius:3px;font-size:12px;line-height:1.5}.osc-svg-icon{height:20px;width:20px;vertical-align:middle}.osc-svg-icon.grayscale{filter:grayscale(1)}.osc-svg-icon.size-gear{width:35px;height:35px}.osc-svg-icon.size-large{height:30px;width:30px}.osc-svg-icon.size-default{height:20px;width:20px}.osc-svg-icon.size-medium{height:18px;width:18px}.osc-svg-icon.size-small{height:14px;width:14px}.osc-svg-icon.size-xsmall{height:10px;width:10px}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }], encapsulation: i0.ViewEncapsulation.ShadowDom });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: OscButtonComponent, decorators: [{
            type: Component,
            args: [{ encapsulation: ViewEncapsulation.ShadowDom, selector: 'lib-osc-button', template: "<button class=\"osc-button size-{{size}} appearance-{{appearance}}\" [disabled]=\"isDisabled\"\n  (click)=\"onClick\" [type]=\"type\">\n  <span ng-if=\"!iconOnly\">\n    <ng-content></ng-content>\n  </span>\n  <!--TODO : will be migrated to icon component in the future -->\n  <svg *ngIf=\"iconOnly\" class=\"osc-svg-icon size-{{iconSize}}\">\n    <use [attr.xlink:href]=\"getIconId()\"></use>\n  </svg>\n  <span *ngIf=\"isDropdown\" class=\"caret\"></span>\n</button>", styles: [".caret{height:20;display:inline-block;width:0;height:0;margin-left:2px;vertical-align:middle;border-top:4px solid;border-right:4px solid transparent;border-left:4px solid transparent}.osc-color-bg-charles{background-color:#1651b0}button.osc-color-bg-charles:hover:enabled{background-color:#00409a}button.osc-color-bg-charles:active:enabled{background-color:#00237a}.osc-color-bd-charles{border:1px solid #1651B0}button.osc-color-bd-charles:hover:enabled{border:1px solid #00409A}button.osc-color-bd-charles:active:enabled{border:1px solid #00237A}.osc-color-txt-on-charles{color:#fff}.osc-color-bg-bunker-hill{background-color:#d2d2d2}button.osc-color-bg-bunker-hill:hover:enabled{background-color:#bababa}button.osc-color-bg-bunker-hill:active:enabled{background-color:#9e9e9e}.osc-color-bd-bunker-hill{border:1px solid #D2D2D2}button.osc-color-bd-bunker-hill:hover:enabled{border:1px solid #BABABA}button.osc-color-bd-bunker-hill:active:enabled{border:1px solid #9E9E9E}.osc-color-txt-on-bunker-hill{color:#333}.osc-color-bg-red-sox{background-color:#bd3039}button.osc-color-bg-red-sox:hover:enabled{background-color:#9b1d2e}button.osc-color-bg-red-sox:active:enabled{background-color:#830a1d}.osc-color-bd-red-sox{border:1px solid #BD3039}button.osc-color-bd-red-sox:hover:enabled{border:1px solid #9B1D2E}button.osc-color-bd-red-sox:active:enabled{border:1px solid #830A1D}.osc-color-txt-on-red-sox{color:#fff}.osc-color-bg-laurel{background-color:#64bc4f}button.osc-color-bg-laurel:hover:enabled{background-color:#4d9a3b}button.osc-color-bg-laurel:active:enabled{background-color:#2f6b23}.osc-color-bd-laurel{border:1px solid #64BC4F}button.osc-color-bd-laurel:hover:enabled{border:1px solid #4D9A3B}button.osc-color-bd-laurel:active:enabled{border:1px solid #2F6B23}.osc-color-txt-on-laurel{color:#fff}.osc-button{display:flex;flex-direction:row;justify-content:center;align-items:center;white-space:nowrap;width:auto;cursor:pointer;gap:4px}.osc-button.appearance-primary{background-color:#1651b0;border:1px solid #1651B0;color:#fff}button.osc-button.appearance-primary:hover:enabled{background-color:#00409a}button.osc-button.appearance-primary:active:enabled{background-color:#00237a}button.osc-button.appearance-primary:hover:enabled{border:1px solid #00409A}button.osc-button.appearance-primary:active:enabled{border:1px solid #00237A}.osc-button.appearance-secondary,.osc-button.appearance-cancel{background-color:#d2d2d2;border:1px solid #D2D2D2;color:#333}button.osc-button.appearance-secondary:hover:enabled,button.osc-button.appearance-cancel:hover:enabled{background-color:#bababa}button.osc-button.appearance-secondary:active:enabled,button.osc-button.appearance-cancel:active:enabled{background-color:#9e9e9e}button.osc-button.appearance-secondary:hover:enabled,button.osc-button.appearance-cancel:hover:enabled{border:1px solid #BABABA}button.osc-button.appearance-secondary:active:enabled,button.osc-button.appearance-cancel:active:enabled{border:1px solid #9E9E9E}.osc-button.appearance-secondary{background-color:#fff}.osc-button.appearance-success{background-color:#64bc4f;border:1px solid #64BC4F;color:#fff}button.osc-button.appearance-success:hover:enabled{background-color:#4d9a3b}button.osc-button.appearance-success:active:enabled{background-color:#2f6b23}button.osc-button.appearance-success:hover:enabled{border:1px solid #4D9A3B}button.osc-button.appearance-success:active:enabled{border:1px solid #2F6B23}.osc-button.appearance-danger{background-color:#bd3039;border:1px solid #BD3039;color:#fff}button.osc-button.appearance-danger:hover:enabled{background-color:#9b1d2e}button.osc-button.appearance-danger:active:enabled{background-color:#830a1d}button.osc-button.appearance-danger:hover:enabled{border:1px solid #9B1D2E}button.osc-button.appearance-danger:active:enabled{border:1px solid #830A1D}.osc-button:focus{outline:2px solid #90CEF1}.osc-button:active,.osc-button :disabled{outline:none}.osc-button:disabled{opacity:40%}.osc-button.size-default{padding:6px 12px;border-radius:4px;font-size:14px;line-height:1.42857143}.osc-button.size-small{padding:5px 10px;border-radius:3px;font-size:12px;line-height:1.5}.osc-button.size-xsmall{padding:1px 5px;border-radius:3px;font-size:12px;line-height:1.5}.osc-svg-icon{height:20px;width:20px;vertical-align:middle}.osc-svg-icon.grayscale{filter:grayscale(1)}.osc-svg-icon.size-gear{width:35px;height:35px}.osc-svg-icon.size-large{height:30px;width:30px}.osc-svg-icon.size-default{height:20px;width:20px}.osc-svg-icon.size-medium{height:18px;width:18px}.osc-svg-icon.size-small{height:14px;width:14px}.osc-svg-icon.size-xsmall{height:10px;width:10px}\n"] }]
        }], ctorParameters: function () { return []; }, propDecorators: { isDropdown: [{
                type: Input
            }], isDisabled: [{
                type: Input
            }], iconOnly: [{
                type: Input
            }], appearance: [{
                type: Input
            }], size: [{
                type: Input
            }], iconName: [{
                type: Input
            }], iconSize: [{
                type: Input
            }], type: [{
                type: Input
            }], onClick: [{
                type: Input
            }] } });

class OscButtonModule {
    constructor(injector) {
        this.injector = injector;
    }
    ngDoBootstrap() {
        const el = createCustomElement(OscButtonComponent, {
            injector: this.injector
        });
        customElements.define(`osc-button`, el);
    }
}
OscButtonModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: OscButtonModule, deps: [{ token: i0.Injector }], target: i0.ɵɵFactoryTarget.NgModule });
OscButtonModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.2", ngImport: i0, type: OscButtonModule, declarations: [OscButtonComponent], imports: [BrowserModule, CommonModule] });
OscButtonModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: OscButtonModule, imports: [BrowserModule, CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.2", ngImport: i0, type: OscButtonModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [BrowserModule, CommonModule],
                    declarations: [OscButtonComponent],
                    entryComponents: [OscButtonComponent]
                }]
        }], ctorParameters: function () { return [{ type: i0.Injector }]; } });

platformBrowserDynamic()
    .bootstrapModule(OscButtonModule)
    .catch(err => console.error(err));

/**
 * Generated bundle index. Do not edit.
 */
//# sourceMappingURL=osc-library.mjs.map
